@@ -15,14 +15,14 @@ from aiohttp_sqlalchemy.views import SAAbstractView, SABaseView, SAView
 
 if TYPE_CHECKING:
     from aiohttp.web import Application
-    from typing import Callable, Iterable, Union, Tuple
+    from typing import Any, Callable, Iterable, Union, Tuple
 
     TSessionFactory = Callable[..., AsyncSession]
     TBindTo = Union[str, Callable[..., AsyncSession]]
     TSABinding = Tuple[TSessionFactory, str, bool]
 
 
-__version__ = '0.15.1'
+__version__ = '0.15.2'
 
 __all__ = ['bind', 'DuplicateAppKeyError', 'DuplicateRequestKeyError',
            'init_db', 'SAAbstractView', 'SABaseView', 'SA_DEFAULT_KEY',
@@ -59,9 +59,7 @@ def bind(bind_to: 'TBindTo', key: str = SA_DEFAULT_KEY, *,
     return bind_to, key, middleware
 
 
-def sa_bind(bind_to: 'TBindTo', key: str = SA_DEFAULT_KEY, *,
-            middleware: bool = True) -> 'TSABinding':
-    return bind(bind_to, key, middleware=middleware)
+sa_bind = bind  # sa_bind is synonym for bind
 
 
 def setup(app: 'Application', bindings: 'Iterable[TSABinding]') -> None:
@@ -76,7 +74,7 @@ def setup(app: 'Application', bindings: 'Iterable[TSABinding]') -> None:
             app.middlewares.append(sa_middleware(key))
 
 
-def __getattr__(name):
+def __getattr__(name: str) -> 'Any':
     if name == 'DEFAULT_KEY':
         msg = "'DEFAULT_KEY' has been deprecated, use 'SA_DEFAULT_KEY'"
         warnings.warn(msg, UserWarning, stacklevel=2)
