@@ -7,22 +7,17 @@ from aiohttp_sqlalchemy.exceptions import DuplicateRequestKeyError
 
 if TYPE_CHECKING:
     from aiohttp.web import Request, StreamResponse
-    from typing import Awaitable, Callable, Union, Type
+    from typing import Any, Awaitable, Callable, Union, Type
 
-    TRequestHandler = Callable[
-        ...,
-        Union[
-            Type[AbstractView],
-            Callable[[Request], Awaitable[StreamResponse]]
-        ]
-    ]
+    TDecorated = Callable[[Request], Awaitable[StreamResponse]]
+    TResult = Callable[..., Union[Type[AbstractView], TDecorated]]
 
 
-def sa_decorator(key: str = SA_DEFAULT_KEY) -> 'TRequestHandler':
+def sa_decorator(key: str = SA_DEFAULT_KEY) -> 'TResult':
     """ SQLAlchemy asynchronous handler decorator. """
-    def wrapper(handler):
+    def wrapper(handler: 'TDecorated') -> 'TDecorated':
         @wraps(handler)
-        async def wrapped(*args, **kwargs) -> 'StreamResponse':
+        async def wrapped(*args: 'Any', **kwargs: 'Any') -> 'StreamResponse':
             request = args[0].request \
                       if isinstance(args[0], AbstractView) \
                       else args[-1]
