@@ -14,18 +14,13 @@ async def init_db(
     metadata: 'MetaData',
     key: str = SA_DEFAULT_KEY,
 ) -> None:
-    session_factory = app.get(key)
+    session_factory = app[key]
     session = session_factory()
     async with session.bind.begin() as connection:
         await connection.run_sync(metadata.create_all)
 
 
-async def sa_init_db(
-    app: 'Application',
-    metadata: 'MetaData',
-    key: str = SA_DEFAULT_KEY,
-) -> None:
-    await init_db(app, metadata, key)
+sa_init_db = init_db  # sa_init_db is synonym for init_db
 
 
 def sa_session(request: 'Request', key: str = SA_DEFAULT_KEY) -> 'AsyncSession':
