@@ -3,7 +3,7 @@ from aiohttp.abc import AbstractView
 from aiohttp.web import View
 from typing import TYPE_CHECKING
 
-from aiohttp_sqlalchemy.constants import DEFAULT_KEY
+from aiohttp_sqlalchemy.constants import SA_DEFAULT_KEY
 
 if TYPE_CHECKING:
     from sqlalchemy.ext.asyncio import AsyncSession
@@ -18,7 +18,7 @@ class SAAbstractView(AbstractView, metaclass=ABCMeta):
 
     Suitable for a specific usage with multiple models.
     """
-    sa_session_key: 'str' = DEFAULT_KEY
+    sa_session_key: 'str' = SA_DEFAULT_KEY
 
     def sa_session(self, key: 'Optional[str]' = None) -> 'AsyncSession':
         return self.request[key or self.sa_session_key]
